.. currentmodule:: disnake_compass.impl

Channel Parser Implementation
=============================

.. automodule:: disnake_compass.impl.parser.channel


Classes
-------

.. attributetable:: disnake_compass.impl.parser.channel.PartialMessageableParser

.. autoclass:: disnake_compass.impl.parser.channel.PartialMessageableParser
    :members:

.. attributetable:: disnake_compass.impl.parser.channel.ChannelParserBase

.. autoclass:: disnake_compass.impl.parser.channel.ChannelParserBase
    :members:

.. note::
    The following classes have the exact same attributes and methods as the
    :class:`~disnake_compass.impl.parser.channel.ChannelParserBase` base class,
    so their attributes and methods have been omitted.


.. autoclass:: disnake_compass.impl.parser.channel.GuildChannelParser

.. autoclass:: disnake_compass.impl.parser.channel.PrivateChannelParser

.. autoclass:: disnake_compass.impl.parser.channel.DMChannelParser

.. autoclass:: disnake_compass.impl.parser.channel.GroupChannelParser

.. autoclass:: disnake_compass.impl.parser.channel.ForumChannelParser

.. autoclass:: disnake_compass.impl.parser.channel.NewsChannelParser

.. autoclass:: disnake_compass.impl.parser.channel.VoiceChannelParser

.. autoclass:: disnake_compass.impl.parser.channel.StageChannelParser

.. autoclass:: disnake_compass.impl.parser.channel.TextChannelParser

.. autoclass:: disnake_compass.impl.parser.channel.ThreadParser

.. autoclass:: disnake_compass.impl.parser.channel.CategoryParser
